slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVGetMat

Returns a Mat object of dense type that shares the memory of the BV object.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVGetMat(BV bv,Mat *A)

Collective on bv

### Input Parameter

| bv | - the basis vectors context

### Output Parameter

| A | - the matrix

### Notes

The returned matrix contains only the active columns. If the content of the Mat is modified, these changes are also done in the BV object. The user must call BVRestoreMat() when no longer needed.

This operation implies a call to BVGetArray(), which may result in data copies.

### See Also

BVRestoreMat(), BVCreateMat(), BVGetArray()

### Level

advanced

### Location

src/sys/classes/bv/interface/bvbasic.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages